anonymise_all: anonymise_all

Description Usage Arguments Value See Also

View source: R/anonymise.R

Description

Simplify application of anonymise function to every column in the dataset

Usage

1
2
anonymise_all(data, add_names = c(""), auto = TRUE, complete = FALSE,
  identify = FALSE, gender = FALSE, quietly = FALSE)

Arguments

data

dataframe or tibble with a row per survey response

add_names

character vector of names to anonymise (optional)

auto

logical indicating whether to look for names to anonymise in the column. Defaults to TRUE.

complete

logical indicating whether to anonymise every capitalised word that doesn't start a sentence. Defaults to FALSE.

identify

logical indicating whether anonymised names should be distinguishable from each other by numbers. Defaults to FALSE.

gender

logical indicating whether to remove references to gender pronouns (he/she him/her etc.). Defaults to FALSE.

quietly

logical indicating whether to suppress warnings for columns that don't contain names

Value

Original dataframe with all columns anonymised

See Also

Other anonymiser functions: anonymise_at, anonymise


chrisbrownlie/surveyr documentation built on Dec. 1, 2019, 12:34 a.m.