clean_at: clean_at

Description Usage Arguments Value See Also

View source: R/clean_column.R

Description

Apply clean() function to multiple specified columns

Usage

1
clean_at(data, ..., num = FALSE, null_response = TRUE)

Arguments

data

dataframe or tibble with a row per survey response

...

columns for the clean() function to be applied to

num

logical indicating whether numbers should be removed as part of cleaning process

null_response

logical indicating whether to remove non-answers (e.g. 'no', 'none', 'na' etc.)

Value

Original dataframe with specified columns cleaned and standardised ready for analysing

See Also

Other preprocess functions: clean_all, clean


chrisbrownlie/surveyr documentation built on Dec. 1, 2019, 12:34 a.m.