Description Usage Arguments Value See Also
Simplify application of anonymise function to every column in the dataset
1 2 |
data |
dataframe or tibble with a row per survey response |
add_names |
character vector of names to anonymise (optional) |
auto |
logical indicating whether to look for names to anonymise in the column. Defaults to TRUE. |
complete |
logical indicating whether to anonymise every capitalised word that doesn't start a sentence. Defaults to FALSE. |
identify |
logical indicating whether anonymised names should be distinguishable from each other by numbers. Defaults to FALSE. |
gender |
logical indicating whether to remove references to gender pronouns (he/she him/her etc.). Defaults to FALSE. |
quietly |
logical indicating whether to suppress warnings for columns that don't contain names |
Original dataframe with all columns anonymised
Other anonymiser functions: anonymise_at,
anonymise
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.